"""
Módulo com funções que tratam da impressão de informações
"""
import sys
from datetime import datetime
from pytz import timezone


def formatar_msg_aviso(msg):
    return f'\033[93m{msg}\033[0m'


def formatar_msg_erro(msg):
    return f'\033[91m{msg}\033[0m'


def finalizar_com_erro(msg_erro):
    print(formatar_msg_erro(f'\nErro ao executar operação:\n{msg_erro}'))
    sys.exit(1)


def imprimir_ok(ocultar_progresso):
    if not ocultar_progresso:
        print('[OK]')


def imprimir_erro(ocultar_progresso):
    if not ocultar_progresso:
        print('[ERRO]')


def imprimir_acao_corrente(acao, ocultar_progresso):
    if not ocultar_progresso:
        print('{:<60}'.format(acao + '...'), end='', flush=True)


def get_str_data_formatada(formato):
    fuso = timezone('America/Sao_Paulo')
    return datetime.now().astimezone(fuso).strftime(formato)



"""
Módulo com configurações gerais
"""

# Campos customizado no VMM
CAMPO_AGRUPAMENTO = ('VMM_MANAGER_AGRUPAMENTO',
                     'Agrupamento da máquina (script vmm_manager).')

CAMPO_ID = ('VMM_MANAGER_ID',
            'Nome da VM informada no inventário (script vmm_manager).')

CAMPO_IMAGEM = ('VMM_MANAGER_IMAGEM',
                'Imagem utilizada para criar a VM (script vmm_manager).')

CAMPO_REGIAO = ('VMM_MANAGER_REGIAO',
                'Região na qual a VM foi criada (script vmm_manager).')

CAMPO_REDE_PRINCIPAL = ('VMM_MANAGER_REDE_PRINCIPAL',
                        'Nome da rede principal da VM (script vmm_manager).')



"""
Representação de uma interface de rede de uma máquina virtual
"""


class VMRede:
    def __init__(self, nome, principal=False):
        self.nome = nome
        self.principal = principal

        self.ips = []

    def __hash__(self):
        return hash(self.nome)

    def __eq__(self, other):
        return isinstance(other, VMRede) and (self.nome == other.nome
                                              and self.principal == other.principal)

    def __repr__(self):
        return f'''
                nome: {self.nome}
                principal: {self.principal}
                ips: {self.ips}
                '''

    def to_dict(self):
        return {
            'nome': self.nome,
            'principal': self.principal,
            'ips': self.ips,
        }
